(***********************************************************************)
(*                                                                     *)
(*                              Ref-indic                              *)
(*                                                                     *)
(*                        Refinement indicators                        *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright (c) 2013-2014 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: display_quantity_components_spec.mli,v 1.18 2014/05/06 12:56:21 fclement Exp $ *)

(** {3 Display quantity components specification} *)

open Refinement_types;;
open Display_types;;
open Scalar_spec;;
open Components_spec;;

module type MAKER =
  functor (Scal : SCALAR) ->
  functor (Comps : COMPONENTS) ->
sig
  module Bb : module type of (Black_box.Make (Scal) (Comps));;
  module St : module type of (State.Make (Scal) (Comps));;
  module H : module type of (History.Make (Scal) (Comps));;
  
  module Dqt : module type of (Display_quantity_types.Make (Scal) (Comps));;
  open Dqt;;
  
  val blank : color;;
  
  val make_pixmaps :
    quantity -> graphics_mode -> display_image_size -> pixmaps
  ;;
  
  val make_lower_left_corners :
    quantity ->
    graphics_mode -> comps_direction -> display_image_size -> length ->
    lower_left_corners
  ;;
  
  val fake_print_pixmaps : print_pixmaps;;
  
  val make_print_pixmaps :
    quantity -> pixmaps -> graphics_mode -> print_pixmaps
  ;;
  
  val fake_alter_pixmaps : scalar_alter_pixmaps;;
  
  val make_alter_pixmaps :
    quantity -> pixmaps -> graphics_mode -> scalar_alter_pixmaps
  ;;
  
  val fake_draw_pixmaps : draw_pixmaps;;
  
  val make_draw_pixmaps :
    quantity -> pixmaps -> lower_left_corners -> graphics_mode -> draw_pixmaps
  ;;
  
  val print_apply :
    (print_pixmap -> Format.formatter -> unit) -> Format.formatter ->
    print_pixmaps -> unit
  ;;
  
  val alter_apply :
    scalar pixmap_iter -> scalar colormap components -> Bb.partitions ->
    scalar_alter_pixmaps -> unit
  ;;
  
  val draw_apply : draw_pixmaps -> unit;;
end
;;
