(***********************************************************************)
(*                                                                     *)
(*                              Ref-indic                              *)
(*                                                                     *)
(*                        Refinement indicators                        *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright (c) 2013-2014 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: worker.mli,v 1.8 2014/06/18 13:33:02 fclement Exp $ *)

(** {3 Generic part of workers for the inversion platform} *)

open Wire_types;;

(** {6 Tasks} *)

type init_engine = Pio.spf -> dimension -> size * partition * coarse_parameter
and grad_engine = Pio.spf -> fine_parameter -> fine_gradient
and optim_engine =
    Pio.spf -> partition -> coarse_parameter -> coarse_parameter * cost
and final_engine = Pio.spf -> fine_parameter -> unit
;;

type task_engines =
  {
   init_engine : init_engine;
   grad_engine : grad_engine;
   optim_engine : optim_engine;
   final_engine : final_engine;
  }
;;

type tasks =
  {
   init : (dimension, size * partition * coarse_parameter * cost) Pio.task;
   grad : (fine_parameter, fine_gradient) Pio.task;
   optim : (partition * coarse_parameter, coarse_parameter * cost) Pio.task;
   final : (fine_parameter, unit) Pio.task;
  }
;;

val make_tasks : task_engines -> tasks;;

type check_valid_dimension =
  Upervasives.function_name -> dimension -> dimension -> unit
;;

val check_valid_dimension : check_valid_dimension;;

type coarse_parameter_to_fine_parameter =
  partition -> coarse_parameter -> fine_parameter
;;

val coarse_parameter_to_fine_parameter : coarse_parameter_to_fine_parameter;;

(** {6 Main loop} *)

val main_loop : tasks -> unit;;
