CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C                              Ref-indic                              C
C                                                                     C
C                        Refinement indicators                        C
C                                                                     C
C               EPI Pomdapi, INRIA Paris - Rocquencourt               C
C                                                                     C
C  Copyright (c) 2013-2014 INRIA.                                     C
C  Institut National de Recherche en Informatique et en Automatique.  C
C  All rights reserved. This file is distributed only by permission.  C
C                                                                     C
C  Hend Ben Ameur <hbenameur@yahoo.ca>                                C
C  Francois Clement <Francois.Clement@inria.fr>                       C
C  Pierre Weis <Pierre.Weis@inria.fr>                                 C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

C     $Id: main.fpp,v 1.7 2014/06/26 10:40:09 fclement Exp $




































































































                    
                   
























































































































































































































      program main
C     Main program.
      
      implicit none
      
C     External routines.
      external initialization, gradient_computation
      external optimization, finalization
      
      call worker_main_body
     +     (initialization, gradient_computation,
     +     optimization, finalization)
      
      end


      subroutine initialization(pp1, lens1, m1)
C     Initialization.
      
      implicit none
      
      include 'worker_error_definition.fh'
      include 'worker_init_definition.fh'
      include 'worker_interface_definition.fh'
      
C     Output arguments.
      integer pp1(9999, 9)
      integer lens1(9)
      real*8 m1(99999)
      
C     Local variables.
      character sbr*14, msg*80
      integer s_len, len, i, j
      
      s_len = 14
      sbr = 'initialization'
      
      dim = 1
      
      call init_model(size_x, size_y, ndS, S, ier, len, msg)
      if (ier .ne. 0) then
         call worker_error_initialization(s_len, sbr, len, msg)
         return
      endif
      
      size = size_x * size_y
      if (size .gt. np_max) then
         call worker_error_too_large_size(s_len, sbr, np_max, size)
         return
      endif
      
      if (ndS .ne. size) then
         call worker_error_wrong_size(s_len, sbr, size, ndS)
         return
      endif
      
      zone_number = dim
      
      do j = 1, dim
         do i = 1, size
            pp1(i, j) = 0
         enddo
         lens1(j) = 1
         m1(j) = 1d0
      enddo
      
      return
      end
      
      
      subroutine gradient_computation(p, g)
C     Gradient computation.
      
      implicit none
      
      include 'worker_error_definition.fh'
      include 'worker_init_definition.fh'
      include 'worker_interface_definition.fh'
      
C     Input arguments.
      real*8 p(9999, 9)
      
C     Output argument.
      real*8 g(9999, 9)
      
C     Local variables.
      character sbr*20
      integer s_len, ndT, i
      real*8 T(np_max), gdS(np_max), gdT(np_max)
      
      s_len = 20
      sbr = 'gradient_computation'
      
      if (size .gt. np_max) then
         call worker_error_too_large_size(s_len, sbr, np_max, size)
         return
      endif
      
      ndT = size
      do i = 1, ndT
         T(i) = p(i, 1)
      enddo
      
      call gradient(ndS, ndT, S, T, gdS, gdT)
      
      do i = 1, ndT
         g(i, 1) = gdT(i)
      enddo
      
      return
      end
      
      
      subroutine optimization(pp, lens, m, cost)
C     Optimal coarse parameter computation.
      
      implicit none
      
      include 'worker_error_definition.fh'
      include 'worker_init_definition.fh'
      include 'worker_interface_definition.fh'
      
C     Input arguments.
      integer pp(9999, 9)
      integer lens(9)
      
C     Input/output argument.
      real*8 m(99999)
      
C     Output argument.
      real*8 cost
      
C     Local variables.
      character sbr*36, msg*80
      integer s_len, ncells, i, proj(np_max), nzones, j, len
      real*8 param(np_max)
      
      s_len = 36
      sbr = 'optimal_coarse_parameter_computation'
      
      if (size .gt. np_max) then
         call worker_error_too_large_size(s_len, sbr, np_max, size)
         return
      endif
      
      ncells = size
      do i = 1, ncells
         proj(i) = pp(i, 1)
      enddo
      
      if (zone_number .gt. np_max) then
         call worker_error_too_large_size
     +        (s_len, sbr, np_max, zone_number)
         return
      endif
      
      if (zone_number .ne. lens(1)) then
         call worker_error_wrong_size(s_len, sbr, lens(1), zone_number)
         return
      endif
      
      nzones = lens(1)
      do j = 1, nzones
         param(j) = m(j)
      enddo
      
      call optim(ncells, proj, nzones, param, ndS, S, cost,
     +     ier, len, msg)
      if (ier .ne. 0) then
         call worker_error_optimization(s_len, sbr, len, msg)
         return
      endif
      
      do j = 1, nzones
         m(j) = param(j)
      enddo
      
      return
      end
      
      
      subroutine finalization(p)
C     Finalization.
      
      implicit none
      
      include 'worker_error_definition.fh'
      include 'worker_init_definition.fh'
      include 'worker_interface_definition.fh'
      
C     Input argument.
      real*8 p(9999, 9)
      
C     Local variables.
      character sbr*12
      integer s_len
      
      s_len = 12
      sbr = 'finalization'
      
      call save_opt_param(s_len, sbr, p)
      if (ier .ne. 0) return
      
      return
      end


      subroutine save_opt_param(s_len, sbr, p)
C     Save the optimal transmissivity parameter.
      
      implicit none
      
      include 'worker_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input argument.
      character sbr*(*)
      integer s_len
      real*8 p(9999, 9)
      
C     Local variables.
      character fname*13
      integer fn_len, i
      
      fn_len = 13
      fname = 'opt_param.dat'
      open(unit=12, file=fname(1:fn_len),
     +     status='unknown', access='sequential', form='formatted',
     +     iostat=ier)
      if (ier .ne. 0) then
         call worker_error_open_failure(s_len, sbr, fn_len, fname)
         return
      endif
      
      do i = 1, size
         write(12, *) p(i, 1)
      enddo
      
      close(12)

      return
      end
